==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/UnreachableCodeEliminator.h <==
// public class soot.jimple.toolkits.scalar.UnreachableCodeEliminator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class bd74bcc5faeeff9f soot_jimple_toolkits_scalar_UnreachableCodeEliminator

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_scalar_UnreachableCodeEliminator_H_
#define _JC_soot_jimple_toolkits_scalar_UnreachableCodeEliminator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object;
struct _jc_soot_toolkits_graph_CompleteUnitGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_refs	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$refs	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$nonrefs	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vmethods	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtable	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtype	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method$visitStmts$7e1c29faf9d635e2(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method_info$visitStmts$7e1c29faf9d635e2;

// Static methods
extern struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method$v$99f44b8c5771fb7a(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*visitStmts$7e1c29faf9d635e2)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vmethods	soot_jimple_toolkits_scalar_UnreachableCodeEliminator;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_refs {
	struct _jc_soot_toolkits_graph_CompleteUnitGraph$object	*stmtGraph;
	struct _jc_java_util_HashSet$object	*visited;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$refs {
    _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_refs	soot_jimple_toolkits_scalar_UnreachableCodeEliminator;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_nonrefs {
	jint	numPruned;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_nonrefs	soot_jimple_toolkits_scalar_UnreachableCodeEliminator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object {
	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtype _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_UnreachableCodeEliminator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_UnreachableCodeEliminator_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/UnreachableCodeEliminator.h <==
// public class soot.jimple.toolkits.scalar.UnreachableCodeEliminator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class bd74bcc5faeeff9f soot_jimple_toolkits_scalar_UnreachableCodeEliminator

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_scalar_UnreachableCodeEliminator_H_
#define _JC_soot_jimple_toolkits_scalar_UnreachableCodeEliminator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object;
struct _jc_soot_toolkits_graph_CompleteUnitGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_refs	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$refs	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$nonrefs	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vmethods	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtable	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtype	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method$visitStmts$7e1c29faf9d635e2(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method_info$visitStmts$7e1c29faf9d635e2;

// Static methods
extern struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$method$v$99f44b8c5771fb7a(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*visitStmts$7e1c29faf9d635e2)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vmethods	soot_jimple_toolkits_scalar_UnreachableCodeEliminator;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_refs {
	struct _jc_soot_toolkits_graph_CompleteUnitGraph$object	*stmtGraph;
	struct _jc_java_util_HashSet$object	*visited;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$refs {
    _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_refs	soot_jimple_toolkits_scalar_UnreachableCodeEliminator;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_nonrefs {
	jint	numPruned;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$sub_nonrefs	soot_jimple_toolkits_scalar_UnreachableCodeEliminator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$object {
	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$vtype _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_UnreachableCodeEliminator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_UnreachableCodeEliminator$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_UnreachableCodeEliminator_H_ */
